streamQsimplified: streamQsimplified

Description Usage Arguments Examples

View source: R/streamQsimplified.R

Description

The function receives a numerical data stream and computes its outliers. The Quality of such stream is defined as Q = 1 - percentage of outliers.

Usage

1
streamQ(datastream)

Arguments

x

Examples

1
##---- Should be DIRECTLY executable !! ----

auroragonzalez/streamQsimplified documentation built on Nov. 3, 2019, 2:01 p.m.