Description Usage Arguments Examples
View source: R/streamQsimplified.R
The function receives a numerical data stream and computes its outliers. The Quality of such stream is defined as Q = 1 - percentage of outliers.
1 | streamQ(datastream)
|
x |
1 | ##---- Should be DIRECTLY executable !! ----
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.